package com.ruoyi.web.controller.board;

import com.ruoyi.board.domain.BoardInfo;
import com.ruoyi.board.service.BoardInfoService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 情报板信息Controller
 *
 * @author HueFu
 * @date 2024-08-06
 */
@RestController
@RequestMapping("/board")
public class BoardInfoController extends BaseController
{
    @Autowired
    private BoardInfoService BoardInfoService;

    /**
     * 查询情报板信息列表
     */
    @PreAuthorize("@ss.hasPermi('board:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(BoardInfo BoardInfo)
    {
        startPage();
        List<BoardInfo> list = BoardInfoService.list();
        return getDataTable(list);
    }

    /**
     * 导出情报板信息列表
     */
    @PreAuthorize("@ss.hasPermi('board:info:export')")
    @Log(title = "情报板信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BoardInfo BoardInfo)
    {
        List<BoardInfo> list = BoardInfoService.list();
        ExcelUtil<BoardInfo> util = new ExcelUtil<BoardInfo>(BoardInfo.class);
        util.exportExcel(response, list, "情报板信息数据");
    }

    /**
     * 获取情报板信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('board:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(BoardInfoService.getById(id));
    }

    /**
     * 新增情报板信息
     */
    @PreAuthorize("@ss.hasPermi('board:info:add')")
    @Log(title = "情报板信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BoardInfo BoardInfo)
    {
        return toAjax(BoardInfoService.save(BoardInfo));
    }

    /**
     * 修改情报板信息
     */
    @PreAuthorize("@ss.hasPermi('board:info:edit')")
    @Log(title = "情报板信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BoardInfo BoardInfo)
    {
        return toAjax(BoardInfoService.saveOrUpdate(BoardInfo));
    }

    /**
     * 删除情报板信息
     */
    @PreAuthorize("@ss.hasPermi('board:info:remove')")
    @Log(title = "情报板信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(BoardInfoService.removeByIds(ids));
    }
}